hotspot/src/share/vm/opto/output.cpp
changeset 30624 2e1803c8a26d
parent 28723 0a36120cb225
child 32082 2a3323e25de1
--- a/hotspot/src/share/vm/opto/output.cpp	Thu May 07 15:34:45 2015 -0700
+++ b/hotspot/src/share/vm/opto/output.cpp	Fri May 08 11:49:20 2015 -0700
@@ -1880,8 +1880,8 @@
   if (!do_scheduling())
     return;
 
-  // Scheduling code works only with pairs (8 bytes) maximum.
-  if (max_vector_size() > 8)
+  // Scheduling code works only with pairs (16 bytes) maximum.
+  if (max_vector_size() > 16)
     return;
 
   TracePhase tp("isched", &timers[_t_instrSched]);